@@ -1,17 +1,16 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.024-5-g9028a42
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.025-3-g153ce3a
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.025';
+our $VERSION = '0.026';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
     'Dist::Zilla::Role::PrereqSource';
 
-use feature 'fc';
 use List::Util 1.33 qw(none any);
 use Git::Wrapper 0.035;
 use Try::Tiny;
@@ -176,7 +175,7 @@ sub _build_contributors
         sub { require Data::Dumper; Data::Dumper->new([ \@contributors ])->Indent(2)->Terse(1)->Dump } ]);
 
     # remove duplicates by email address, keeping the latest associated name
-    @contributors = uniq_by { fc((/(<[^>]+>)/g)[-1]) } @contributors;
+    @contributors = uniq_by { __fc((/(<[^>]+>)/g)[-1]) } @contributors;
 
     @contributors = Unicode::Collate->new(level => 1)->sort(@contributors) if $self->order_by eq 'name';
 
@@ -191,7 +190,7 @@ sub _build_contributors
 
     if (not $self->include_releaser and my $releaser = $self->_releaser)
     {
-        @contributors = grep { fc $_ ne fc $releaser } @contributors;
+        @contributors = grep { __fc($_) ne __fc($releaser) } @contributors;
     }
 
     if ($self->remove)
@@ -253,6 +252,10 @@ sub _git
     return @result;
 }
 
+# use casefolding when available; otherwise, fallback to lower-casing.
+sub __fc { goto ("$]" >= '5.016' ? \&CORE::fc : \&__lc) }
+sub __lc { lc $_[0] }   # not callable via \&CORE::lc
+
 __PACKAGE__->meta->make_immutable;
 
 __END__
@@ -267,7 +270,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 SYNOPSIS
 
@@ -284,6 +287,13 @@ data is stuffed into other locations, including stashes -- if other plugins
 wish to work with this information, they should extract it from the
 distribution metadata.
 
+=for stopwords unicode casefolding
+
+=head1 RECOMMENDED PERL VERSION
+
+This module uses unicode comparison routines as well as casefolding semantics
+(when available); Perl 5.016 is recommended.
+
 =head1 CONFIGURATION OPTIONS
 
 =head2 C<include_authors>
